@@ -18,14 +18,16 @@ fail() {
     exit 1
 }
 
-# Create tarball
 if [ -d "$1"  ]; then
     GIT_SRC="$(readlink -m $1)"
     RWSRCDIR="$TMPDIR/src-rw"
     mkdir -p $RWSRCDIR
     unionfs-fuse -o cow -o allow_other,use_ino,suid,dev,nonempty $RWSRCDIR=RW:$GIT_SRC=RO $SRCDIR
     pushd $SRCDIR
-    VERSION=$(git describe)
+    BRANCH="$(git rev-parse --abbrev-ref HEAD)"
+    test -n "$(git status --porcelain)" && DIRTY_GIT="*" || DIRTY_GIT=""
+    VERSION="$(git describe)${DIRTY_GIT}"
+    COMMENT="OAR ${VERSION} (git branch ${BRANCH})"
     popd
     [ -n "${VERSION}" ] || fail "error: fail to retrieve OAR version"
 else
@@ -38,6 +40,7 @@ else
         TARBALL="$(readlink -m $TARBALL)"
     fi
     VERSION=$(tar xfz $TARBALL --wildcards "*/sources/core/common-libs/lib/OAR/Version.pm" --to-command "grep -e 'my \$OARVersion'" | sed -e 's/^[^"]\+"\(.\+\)";$/\1/')
+    COMMENT="OAR ${VERSION} (tarball)"
     tar xf $TARBALL -C $SRCDIR
     [ -n "${VERSION}" ] || fail "error: fail to retrieve OAR version"
     SRCDIR=$SRCDIR/oar-${VERSION}
@@ -87,12 +90,12 @@ sed -e "s/^\(username.*\)oar.*/\1oar_ro/" -i /etc/oar/monika.conf
 sed -e "s/^\(password.*\)oar.*/\1oar_ro/" -i /etc/oar/monika.conf
 sed -e "s/^\(dbtype.*\)mysql.*/\1psql/" -i /etc/oar/monika.conf
 sed -e "s/^\(dbport.*\)3306.*/\15432/" -i /etc/oar/monika.conf
-sed -e "s/^\(hostname.*\)localhost.*/\1services/" -i /etc/oar/monika.conf
+sed -e "s/^\(hostname.*\)localhost.*/\1server/" -i /etc/oar/monika.conf
 
 
 # Edit oar.conf
 sed -e 's/^LOG_LEVEL\=\"2\"/LOG_LEVEL\=\"3\"/' -i /etc/oar/oar.conf
-sed -e 's/^DB_HOSTNAME\=.*/DB_HOSTNAME\=\"services\"/' -i /etc/oar/oar.conf
+sed -e 's/^DB_HOSTNAME\=.*/DB_HOSTNAME\=\"server\"/' -i /etc/oar/oar.conf
 sed -e 's/^SERVER_HOSTNAME\=.*/SERVER_HOSTNAME\=\"server\"/' -i /etc/oar/oar.conf
 sed -e 's/^#\(TAKTUK_CMD\=\"\/usr\/bin\/taktuk \-t 30 \-s\".*\)/\1/' -i /etc/oar/oar.conf
 sed -e 's/^#\(PINGCHECKER_TAKTUK_ARG_COMMAND\=\"broadcast exec timeout 5 kill 9 \[ true \]\".*\)/\1/' -i /etc/oar/oar.conf
@@ -108,13 +111,14 @@ sed -e 's/^\(DB_BASE_LOGIN_RO\)=.*/\1="oar_ro"/' -i /etc/oar/oar.conf
 # Configure phppgadmin
 sed -i "s/# allow from all/allow from all/g" /etc/apache2/conf.d/phppgadmin
 sed -i "s/\$conf\['extra_login_security'\] = true;/\$conf\['extra_login_security'\] = false;/g" /etc/phppgadmin/config.inc.php
-sed -i "s/\$conf\['servers'\]\[0\]\['host'\] = 'localhost';/\$conf\['servers'\]\[0\]\['host'\] = 'services';/g" /etc/phppgadmin/config.inc.php
+sed -i "s/\$conf\['servers'\]\[0\]\['host'\] = 'localhost';/\$conf\['servers'\]\[0\]\['host'\] = 'server';/g" /etc/phppgadmin/config.inc.php
 
 ## Visualization tools
 # Configure drawgantt-svg
 sed -i "s/\$CONF\['db_type'\]=\"mysql\"/\$CONF\['db_type'\]=\"pg\"/g" /etc/oar/drawgantt-config.inc.php
-sed -i "s/\$CONF\['db_server'\]=\"127.0.0.1\"/\$CONF\['db_server'\]=\"services\"/g" /etc/oar/drawgantt-config.inc.php
+sed -i "s/\$CONF\['db_server'\]=\"127.0.0.1\"/\$CONF\['db_server'\]=\"server\"/g" /etc/oar/drawgantt-config.inc.php
 sed -i "s/\$CONF\['db_port'\]=\"3306\"/\$CONF\['db_port'\]=\"5432\"/g" /etc/oar/drawgantt-config.inc.php
 sed -i "s/\"My OAR resources\"/\"Docker oardocker resources\"/g" /etc/oar/drawgantt-config.inc.php
 
 echo "$VERSION" | tee /oar_version
+echo "$COMMENT"
