@@ -18,14 +18,16 @@ fail() {
     exit 1
 }
 
-# Create tarball
 if [ -d "$1"  ]; then
     GIT_SRC="$(readlink -m $1)"
     RWSRCDIR="$TMPDIR/src-rw"
     mkdir -p $RWSRCDIR
     unionfs-fuse -o cow -o allow_other,use_ino,suid,dev,nonempty $RWSRCDIR=RW:$GIT_SRC=RO $SRCDIR
     pushd $SRCDIR
-    VERSION=$(git describe)
+    BRANCH="$(git rev-parse --abbrev-ref HEAD)"
+    test -n "$(git status --porcelain)" && DIRTY_GIT="*" || DIRTY_GIT=""
+    VERSION="$(git describe)${DIRTY_GIT}"
+    COMMENT="OAR ${VERSION} (git branch ${BRANCH})"
     popd
     [ -n "${VERSION}" ] || fail "error: fail to retrieve OAR version"
 else
@@ -38,6 +40,7 @@ else
         TARBALL="$(readlink -m $TARBALL)"
     fi
     VERSION=$(tar xfz $TARBALL --wildcards "*/sources/core/common-libs/lib/OAR/Version.pm" --to-command "grep -e 'my \$OARVersion'" | sed -e 's/^[^"]\+"\(.\+\)";$/\1/')
+    COMMENT="OAR ${VERSION} (tarball)"
     tar xf $TARBALL -C $SRCDIR
     [ -n "${VERSION}" ] || fail "error: fail to retrieve OAR version"
     SRCDIR=$SRCDIR/oar-${VERSION}
@@ -78,15 +81,11 @@ sed -e 's/^\(DB_BASE_PASSWD\)=.*/\1="oar"/' -i /etc/oar/oar.conf
 sed -e 's/^\(DB_BASE_LOGIN\)=.*/\1="oar"/' -i /etc/oar/oar.conf
 sed -e 's/^\(DB_BASE_PASSWD_RO\)=.*/\1="oar_ro"/' -i /etc/oar/oar.conf
 sed -e 's/^\(DB_BASE_LOGIN_RO\)=.*/\1="oar_ro"/' -i /etc/oar/oar.conf
-# Use cpuset inside container
-sudo sed -i 's/job_resource_manager_cgroups\.pl/job_resource_manager\.pl/g' /etc/oar/oar.conf
 
-sed -e 's/^DB_HOSTNAME\=.*/DB_HOSTNAME\=\"services\"/' -i /etc/oar/oar.conf
+sed -e 's/^DB_HOSTNAME\=.*/DB_HOSTNAME\=\"server\"/' -i /etc/oar/oar.conf
 sed -e 's/^SERVER_HOSTNAME\=.*/SERVER_HOSTNAME\=\"server\"/' -i /etc/oar/oar.conf
 
-sed -e 's/#exit/exit/' -i /etc/oar/job_resource_manager.pl
-
-chown oar:oar /etc/oar/job_resource_manager.pl
-chmod +x /etc/oar/job_resource_manager.pl
+sed -e 's/#exit/exit/' -i /etc/oar/job_resource_manager_cgroups.pl
 
 echo "$VERSION" | tee /oar_version
+echo "$COMMENT"
